# Scikit-learn-extra Developer Documentation
## Installation Instructions:
### scikit-learn-extra Requires:
- Python (>= 3.5)
- scikit-learn(>=0.21)
- Cython (>0.28)
### User Installation:
You can install scikit-learn-extra using this command: 
`pip install https://github.com/scikit-learn-contrib/scikit-learn-extra/archive/master.zip`

